==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/REVISIONDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for REVISIONDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="REVISIONDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "REVISIONDETAILS_Type", propOrder = {
    "requestby",
    "daterequested",
    "approvedby",
    "approvedate",
    "revisionreason"
})
public class REVISIONDETAILS_Type {

    @XmlElement(name = "REQUESTBY")
    protected USERID_Type requestby;
    @XmlElement(name = "DATEREQUESTED")
    protected DATETIME daterequested;
    @XmlElement(name = "APPROVEDBY")
    protected USERID_Type approvedby;
    @XmlElement(name = "APPROVEDATE")
    protected DATETIME approvedate;
    @XmlElement(name = "REVISIONREASON")
    protected String revisionreason;

    /**
     * Gets the value of the requestby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getREQUESTBY() {
        return requestby;
    }

    /**
     * Sets the value of the requestby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setREQUESTBY(USERID_Type value) {
        this.requestby = value;
    }

    /**
     * Gets the value of the daterequested property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Sets the value of the daterequested property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Gets the value of the approvedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVEDBY() {
        return approvedby;
    }

    /**
     * Sets the value of the approvedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVEDBY(USERID_Type value) {
        this.approvedby = value;
    }

    /**
     * Gets the value of the approvedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Sets the value of the approvedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Gets the value of the revisionreason property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Sets the value of the revisionreason property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/REVISIONDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour REVISIONDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="REVISIONDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "REVISIONDETAILS_Type", propOrder = {
    "requestby",
    "daterequested",
    "approvedby",
    "approvedate",
    "revisionreason"
})
public class REVISIONDETAILS_Type {

    @XmlElement(name = "REQUESTBY")
    protected USERID_Type requestby;
    @XmlElement(name = "DATEREQUESTED")
    protected DATETIME daterequested;
    @XmlElement(name = "APPROVEDBY")
    protected USERID_Type approvedby;
    @XmlElement(name = "APPROVEDATE")
    protected DATETIME approvedate;
    @XmlElement(name = "REVISIONREASON")
    protected String revisionreason;

    /**
     * Obtient la valeur de la propriété requestby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getREQUESTBY() {
        return requestby;
    }

    /**
     * Définit la valeur de la propriété requestby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setREQUESTBY(USERID_Type value) {
        this.requestby = value;
    }

    /**
     * Obtient la valeur de la propriété daterequested.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Définit la valeur de la propriété daterequested.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Obtient la valeur de la propriété approvedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVEDBY() {
        return approvedby;
    }

    /**
     * Définit la valeur de la propriété approvedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVEDBY(USERID_Type value) {
        this.approvedby = value;
    }

    /**
     * Obtient la valeur de la propriété approvedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Définit la valeur de la propriété approvedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Obtient la valeur de la propriété revisionreason.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Définit la valeur de la propriété revisionreason.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

}
